@@ -160,14 +160,20 @@ pub fn parse_file_size(input: &str) -> Result<u64, ParseFileSizeError> {
     Ok((num * base.pow(exponent) as f64) as u64)
 }
 
-fn print_version() {
-    println!(
-        "librespot {semver} {sha} (Built on {build_date}, Build ID: {build_id})",
+fn get_version_string() -> String {
+    #[cfg(debug_assertions)]
+    const BUILD_PROFILE: &str = "debug";
+    #[cfg(not(debug_assertions))]
+    const BUILD_PROFILE: &str = "release";
+
+    format!(
+        "librespot {semver} {sha} (Built on {build_date}, Build ID: {build_id}, Profile: {build_profile})",
         semver = version::SEMVER,
         sha = version::SHA_SHORT,
         build_date = version::BUILD_DATE,
-        build_id = version::BUILD_ID
-    );
+        build_id = version::BUILD_ID,
+        build_profile = BUILD_PROFILE
+    )
 }
 
 struct Setup {
@@ -242,7 +248,7 @@ fn get_setup(args: &[String]) -> Setup {
     ).optopt(
         "",
         SYSTEM_CACHE,
-        "Path to a directory where system files (credentials, volume) will be cached. Can be different from cache option value.",
+        "Path to a directory where system files (credentials, volume) will be cached. May be different from the cache option value.",
         "PATH",
     ).optopt(
         "",
@@ -251,7 +257,7 @@ fn get_setup(args: &[String]) -> Setup {
         "SIZE"
     ).optflag("", DISABLE_AUDIO_CACHE, "Disable caching of the audio data.")
     .optopt("n", NAME, "Device name.", "NAME")
-    .optopt("", DEVICE_TYPE, "Displayed device type.", "TYPE")
+    .optopt("", DEVICE_TYPE, "Displayed device type. Defaults to 'Speaker'.", "TYPE")
     .optopt(
         BITRATE,
         "bitrate",
@@ -264,14 +270,14 @@ fn get_setup(args: &[String]) -> Setup {
         "Run PROGRAM when a playback event occurs.",
         "PROGRAM",
     )
-    .optflag("", EMIT_SINK_EVENTS, "Run program set by --onevent before sink is opened and after it is closed.")
+    .optflag("", EMIT_SINK_EVENTS, "Run PROGRAM set by --onevent before sink is opened and after it is closed.")
     .optflag("v", VERBOSE, "Enable verbose output.")
     .optflag("V", VERSION, "Display librespot version string.")
-    .optopt("u", USERNAME, "Username to sign in with.", "USERNAME")
-    .optopt("p", PASSWORD, "Password", "PASSWORD")
+    .optopt("u", USERNAME, "Username used to sign in with.", "USERNAME")
+    .optopt("p", PASSWORD, "Password used to sign in with.", "PASSWORD")
     .optopt("", PROXY, "HTTP proxy to use when connecting.", "URL")
-    .optopt("", AP_PORT, "Connect to AP with specified port. If no AP with that port are present fallback AP will be used. Available ports are usually 80, 443 and 4070.", "PORT")
-    .optflag("", DISABLE_DISCOVERY, "Disable discovery mode.")
+    .optopt("", AP_PORT, "Connect to an AP with a specified port. If no AP with that port is present a fallback AP will be used. Available ports are usually 80, 443 and 4070.", "PORT")
+    .optflag("", DISABLE_DISCOVERY, "Disable zeroconf discovery mode.")
     .optopt(
         "",
         BACKEND,
@@ -281,7 +287,7 @@ fn get_setup(args: &[String]) -> Setup {
     .optopt(
         "",
         DEVICE,
-        "Audio device to use. Use '?' to list options if using alsa, portaudio or rodio.",
+        "Audio device to use. Use '?' to list options if using alsa, portaudio or rodio. Defaults to the backend's default.",
         "NAME",
     )
     .optopt(
@@ -293,10 +299,10 @@ fn get_setup(args: &[String]) -> Setup {
     .optopt(
         "",
         DITHER,
-        "Specify the dither algorithm to use - [none, gpdf, tpdf, tpdf_hp]. Defaults to 'tpdf' for formats S16, S24, S24_3 and 'none' for other formats.",
+        "Specify the dither algorithm to use {none|gpdf|tpdf|tpdf_hp}. Defaults to 'tpdf' for formats S16, S24, S24_3 and 'none' for other formats.",
         "DITHER",
     )
-    .optopt("m", MIXER_TYPE, "Mixer to use {alsa|softvol}.", "MIXER")
+    .optopt("m", MIXER_TYPE, "Mixer to use {alsa|softvol}. Defaults to softvol", "MIXER")
     .optopt(
         "",
         "mixer-name", // deprecated
@@ -306,7 +312,7 @@ fn get_setup(args: &[String]) -> Setup {
     .optopt(
         "",
         ALSA_MIXER_CONTROL,
-        "Alsa mixer control, e.g. 'PCM' or 'Master'. Defaults to 'PCM'.",
+        "Alsa mixer control, e.g. 'PCM', 'Master' or similar. Defaults to 'PCM'.",
         "NAME",
     )
     .optopt(
@@ -342,13 +348,13 @@ fn get_setup(args: &[String]) -> Setup {
     .optopt(
         "",
         ZEROCONF_PORT,
-        "The port the internal server advertised over zeroconf uses.",
+        "The port the internal server advertises over zeroconf.",
         "PORT",
     )
     .optflag(
         "",
         ENABLE_VOLUME_NORMALISATION,
-        "Play all tracks at the same volume.",
+        "Play all tracks at approximately the same apparent volume.",
     )
     .optopt(
         "",
@@ -371,19 +377,19 @@ fn get_setup(args: &[String]) -> Setup {
     .optopt(
         "",
         NORMALISATION_THRESHOLD,
-        "Threshold (dBFS) to prevent clipping. Defaults to -2.0.",
+        "Threshold (dBFS) at which the dynamic limiter engages to prevent clipping. Defaults to -2.0.",
         "THRESHOLD",
     )
     .optopt(
         "",
         NORMALISATION_ATTACK,
-        "Attack time (ms) in which the dynamic limiter is reducing gain. Defaults to 5.",
+        "Attack time (ms) in which the dynamic limiter reduces gain. Defaults to 5.",
         "TIME",
     )
     .optopt(
         "",
         NORMALISATION_RELEASE,
-        "Release or decay time (ms) in which the dynamic limiter is restoring gain. Defaults to 100.",
+        "Release or decay time (ms) in which the dynamic limiter restores gain. Defaults to 100.",
         "TIME",
     )
     .optopt(
@@ -395,7 +401,7 @@ fn get_setup(args: &[String]) -> Setup {
     .optopt(
         "",
         VOLUME_CTRL,
-        "Volume control type {cubic|fixed|linear|log}. Defaults to log.",
+        "Volume control scale type {cubic|fixed|linear|log}. Defaults to log.",
         "VOLUME_CTRL"
     )
     .optopt(
@@ -417,7 +423,7 @@ fn get_setup(args: &[String]) -> Setup {
     .optflag(
         "",
         PASSTHROUGH,
-        "Pass raw stream to output, only works for pipe and subprocess.",
+        "Pass a raw stream to the output. Only works with the pipe and subprocess backends.",
     );
 
     let matches = match opts.parse(&args[1..]) {
@@ -438,20 +444,14 @@ fn get_setup(args: &[String]) -> Setup {
     }
 
     if matches.opt_present(VERSION) {
-        print_version();
+        println!("{}", get_version_string());
         exit(0);
     }
 
     let verbose = matches.opt_present(VERBOSE);
     setup_logging(verbose);
 
-    info!(
-        "librespot {semver} {sha} (Built on {build_date}, Build ID: {build_id})",
-        semver = version::SEMVER,
-        sha = version::SHA_SHORT,
-        build_date = version::BUILD_DATE,
-        build_id = version::BUILD_ID
-    );
+    info!("{}", get_version_string());
 
     let backend_name = matches.opt_str(BACKEND);
     if backend_name == Some("?".into()) {
